<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://competition.demo.getfoundni.co.uk/
 * @since      1.0.0
 *
 * @package    Gfni_Spot_The_Ball_Addon
 * @subpackage Gfni_Spot_The_Ball_Addon/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Gfni_Spot_The_Ball_Addon
 * @subpackage Gfni_Spot_The_Ball_Addon/includes
 * @author     Get Found NI <ryan@getfoundni.co.uk>
 */
class Gfni_Spot_The_Ball_Addon {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Gfni_Spot_The_Ball_Addon_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'GFNI_SPOT_THE_BALL_ADDON_VERSION' ) ) {
			$this->version = GFNI_SPOT_THE_BALL_ADDON_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'gfni-spot-the-ball-addon';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Gfni_Spot_The_Ball_Addon_Loader. Orchestrates the hooks of the plugin.
	 * - Gfni_Spot_The_Ball_Addon_i18n. Defines internationalization functionality.
	 * - Gfni_Spot_The_Ball_Addon_Admin. Defines all hooks for the admin area.
	 * - Gfni_Spot_The_Ball_Addon_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-gfni-spot-the-ball-addon-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-gfni-spot-the-ball-addon-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-gfni-spot-the-ball-addon-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-gfni-spot-the-ball-addon-public.php';

		$this->loader = new Gfni_Spot_The_Ball_Addon_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Gfni_Spot_The_Ball_Addon_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Gfni_Spot_The_Ball_Addon_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Gfni_Spot_The_Ball_Addon_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );

		$this->loader->add_action( 'acf/init', $plugin_admin, 'add_spot_the_ball_option'); 
		$this->loader->add_action( 'add_meta_boxes', $plugin_admin, 'woocommerce_simple_lottery_meta' );

		$this->loader->add_action( 'save_post', $plugin_admin, 'xy_save_postdata' );
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Gfni_Spot_The_Ball_Addon_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );

		$this->loader->add_action( 'woocommerce_before_add_to_cart_button', $plugin_public, 'add_spot_the_ball_photo' ); 

		$this->loader->add_action( 'woocommerce_add_to_cart', $plugin_public, 'split_cart_items_by_quantity', 10, 6); 
		
		$this->loader->add_action( 'woocommerce_checkout_create_order_line_item', $plugin_public, 'cfwc_add_custom_data_to_order', 10, 4 ); 
 
		$this->loader->add_filter( 'woocommerce_cart_item_name', $plugin_public, 'guesses_cart_item_name', 10, 3 );
		$this->loader->add_filter( 'woocommerce_add_cart_item_data', $plugin_public, 'filter_add_cart_item_data', 10, 4 );

		$this->loader->add_filter( 'woocommerce_cart_item_quantity', $plugin_public, 'wc_cart_item_quantity', 10, 3 );
		$this->loader->add_filter( 'woocommerce_add_to_cart_validation', $plugin_public, 'validate_custom_field', 11, 4 ); 
  
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Gfni_Spot_The_Ball_Addon_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
